==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/template/am_default/mag_overview.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="mag_overview.php" method="post">

<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "mag_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table border="0" width="100%" cellspacing="4" cellpadding="0">
				<tr>
					<td class="txt_title">
						<?php echo $lang['section_search'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<input type="text" name="search_text" size="18" class="formInput" value="<?php if(isset($search)) { echo $search;}?>" /><br />
					</td>
			    </tr>
				<tr>
					<td>
						<select name="search_genre_id" class="formInput">
							<option value="0"><?php echo $lang['txt_all_genre'];?></option>
							<?php
							foreach($lang['arr_genre'] as $key => $i):
								$selected = "";
								if(isset($search_genre_id) && $search_genre_id == $key) {
									$selected = " selected";
								}
								print "<option value='" . $key . "'" . $selected . ">" . $i . "</option>";
							endforeach;
							?>
						</select>
					</td>
			    </tr>
				<tr>
					<td align="right">
						<input type="submit" name="search" value="<?php echo $lang['sub_search'];?>" class="formInput" /><br />
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="275" valign="top">

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_blogs'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($blogs)) {
				foreach($blogs as $key => $i):
				if (isset($cms_blogs[$key]['cms_sticky']) && $cms_blogs[$key]['cms_sticky'] = 1) {
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="4" cellspacing="2" border="0" class="picture">
							<tr>
								<td width="80" rowspan="2" valign="top">
									<a href="mag_item.php?blog_id=<?php echo $i['blog_id'];?>"><img align="left" src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture" title="<?php echo $i['image']['file_title'];?>"></a>
								</td>
								<td valign="top" class="bg2">
									<a href="mag_item.php?blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_title'];?></a><br />
								</td>
							</tr>
							<tr>
								<td valign="top" class="bg4">
									<span class="txt_footer"><?php echo $i['blog_create_datetime'];?>
									&nbsp;/&nbsp;
									<?php echo $lang['txt_genre'];?>: <?php if (isset($i['genre_id']) && $i['genre_id'] > 0) { echo $lang['arr_genre'][$i['genre_id']];}?></span><br />
									<span class="txt_footer"><?php echo $i['blog_synopsis'];?></span><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				}
				endforeach;
				}
				?>
				<?php
				if (isset($blogs)) {
				foreach($blogs as $key => $i):
				if (!isset($cms_blogs[$key]['cms_sticky']) || $cms_blogs[$key]['cms_sticky'] != 1) {
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['blog_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				}
				endforeach;
				}
				?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_subjects'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($subjects)) {
				foreach($subjects as $key => $i):
				if (isset($cms_subjects[$key]['cms_sticky']) && $cms_subjects[$key]['cms_sticky'] = 1) {
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="4" cellspacing="2" border="0" class="picture">
							<tr>
								<td width="80" rowspan="2" valign="top">
									<a href="mag_item.php?subject_id=<?php echo $i['subject_id'];?>"><img align="left" src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture" title="<?php echo $i['image']['file_title'];?>"></a>
								</td>
								<td valign="top" class="bg2">
									<a href="mag_item.php?subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_title'];?></a><br />
								</td>
							</tr>
							<tr>
								<td valign="top" class="bg4">
									<span class="txt_footer"><?php echo $i['subject_create_datetime'];?>
									&nbsp;/&nbsp;
									<?php echo $lang['txt_genre'];?>: <?php if (isset($i['genre_id']) && $i['genre_id'] > 0) { echo $lang['arr_genre'][$i['genre_id']];}?></span><br />
									<span class="txt_footer"><?php echo $i['subject_body'];?></span><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				}
				endforeach;
				}
				?>
				<?php
				if (isset($subjects)) {
				foreach($subjects as $key => $i):
				if (!isset($cms_subjects[$key]['cms_sticky']) || $cms_subjects[$key]['cms_sticky'] != 1) {
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['subject_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				}
				endforeach;
				}
				?>
			</table>

		</td>

		<td width="20">&nbsp;</td>

		<td width="275" valign="top">
 			<table border="0" cellspacing="4" cellpadding="0" width="100%">
 				<tr>
 					<td class="txt_title" align="right">
 						<?php echo $lang['section_polls'];?><br />
 						<hr />
 					</td>
 				</tr>
 				<?php
				if (isset($polls)) {
 				foreach($polls as $key => $i):
 				?>
 				<tr>
 					<td valign="top">
 						<?php
						$poll = $i;
 						include $templatePath . "poll.inc.tpl.php";
 						?>
 					</td>
 			    </tr>
				<tr>
 					<td valign="top" class="txt_footer" align="right">
 						<a href="mag_item.php?poll_id=<?php echo $i['poll_id'];?>" class="txt_footer_lnk">visit poll</a><br />
 					</td>
 			    </tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
 				<?php
 				endforeach;
				}
 				?>
 			</table>
			

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_library_items'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($library_items)) {
				foreach($library_items as $key => $i):
				if (isset($cms_library_items[$key]['cms_sticky']) && $cms_library_items[$key]['cms_sticky'] = 1) {
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="4" cellspacing="2" border="0" class="picture">
							<tr>
								<td width="80" rowspan="2" valign="top">
									<a href="mag_item.php?library_id=<?php echo $i['library_id'];?>"><img align="left" src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture" title="<?php echo $i['image']['file_title'];?>"></a>
								</td>
								<td valign="top" class="bg2">
									<a href="mag_item.php?library_id=<?php echo $i['library_id'];?>"><?php echo $i['library_title'];?></a><br />
								</td>
							</tr>
							<tr>
								<td valign="top" class="bg4">
									<span class="txt_footer"><?php echo $i['library_create_datetime'];?>
									&nbsp;/&nbsp;
									<?php echo $lang['txt_genre'];?>: <?php if (isset($i['genre_id']) && $i['genre_id'] > 0) { echo $lang['arr_genre'][$i['genre_id']];}?></span><br />
									<span class="txt_footer"><?php echo $i['library_synopsis'];?></span><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				}
				endforeach;
				}
				?>
				<?php
				if (isset($library_items)) {
				foreach($library_items as $key => $i):
				if (!isset($cms_library_items[$key]['cms_sticky']) || $cms_library_items[$key]['cms_sticky'] != 1) {
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?library_id=<?php echo $i['library_id'];?>"><?php echo $i['library_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['library_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				}
				endforeach;
				}
				?>
			</table>
		</td>
	</tr>
</table>
</form>

==> aroundme_0_4_1.zip: aroundme_0_4_1/www/aroundme_0_4_1/template/am_default/mag_overview.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="mag_overview.php" method="post">

<table width="770" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "mag_menu.inc.tpl.php";
			?>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table border="0" width="100%" cellspacing="4" cellpadding="0">
				<tr>
					<td class="txt_title">
						<?php echo $lang['section_search'];?><br />
						<hr />
					</td>
				</tr>
				<tr>
					<td>
						<input type="text" name="search_text" size="18" class="formInput" value="<?php if(isset($search)) { echo $search;}?>" /><br />
					</td>
			    </tr>
				<tr>
					<td>
						<select name="search_genre_id" class="formInput">
							<option value="0"><?php echo $lang['txt_all_genre'];?></option>
							<?php
							foreach($lang['arr_genre'] as $key => $i):
								$selected = "";
								if(isset($search_genre_id) && $search_genre_id == $key) {
									$selected = " selected";
								}
								print "<option value='" . $key . "'" . $selected . ">" . $i . "</option>";
							endforeach;
							?>
						</select>
					</td>
			    </tr>
				<tr>
					<td align="right">
						<input type="submit" name="search" value="<?php echo $lang['sub_search'];?>" class="formInput" /><br />
					</td>
				</tr>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="52" alt="" /><br />

			<?php
			include $templatePath . "logo.inc.tpl.php";
			?>
		</td>

		<td width="20">&nbsp;</td>

		<td width="275" valign="top">

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_blogs'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($blogs)) {
				foreach($blogs as $key => $i):
				foreach($cms_blogs as $key1 => $cms):
				if (($cms['item_id'] == $i['blog_id']) && $cms['cms_sticky'] == 1) {
				unset($blogs[$key]);
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="4" cellspacing="2" border="0" class="picture">
							<tr>
								<td width="80" rowspan="2" valign="top">
									<a href="mag_item.php?blog_id=<?php echo $i['blog_id'];?>"><img align="left" src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture" title="<?php echo $i['image']['file_title'];?>"></a>
								</td>
								<td valign="top" class="bg2">
									<a href="mag_item.php?blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_title'];?></a><br />
								</td>
							</tr>
							<tr>
								<td valign="top" class="bg4">
									<span class="txt_footer"><?php echo $i['blog_create_datetime'];?>
									&nbsp;/&nbsp;
									<?php echo $lang['txt_genre'];?>: <?php if (isset($i['genre_id']) && $i['genre_id'] > 0) { echo $lang['arr_genre'][$i['genre_id']];}?></span><br />
									<span class="txt_footer"><?php echo $i['blog_synopsis'];?></span><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				}
				endforeach;
				endforeach;
				}
				?>
				<?php
				if (isset($blogs)) {
				foreach($blogs as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['blog_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				?>
			</table>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_subjects'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($subjects)) {
				foreach($subjects as $key => $i):
				foreach($cms_subjects as $key1 => $cms):
				if (($cms['item_id'] == $i['subject_id']) && $cms['cms_sticky'] == 1) {
				unset($subjects[$key]);
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="4" cellspacing="2" border="0" class="picture">
							<tr>
								<td width="80" rowspan="2" valign="top">
									<a href="mag_item.php?subject_id=<?php echo $i['subject_id'];?>"><img align="left" src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture" title="<?php echo $i['image']['file_title'];?>"></a>
								</td>
								<td valign="top" class="bg2">
									<a href="mag_item.php?subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_title'];?></a><br />
								</td>
							</tr>
							<tr>
								<td valign="top" class="bg4">
									<span class="txt_footer"><?php echo $i['subject_create_datetime'];?>
									&nbsp;/&nbsp;
									<?php echo $lang['txt_genre'];?>: <?php if (isset($i['genre_id']) && $i['genre_id'] > 0) { echo $lang['arr_genre'][$i['genre_id']];}?></span><br />
									<span class="txt_footer"><?php echo $i['subject_body'];?></span><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				}
				endforeach;
				endforeach;
				}
				?>
				<?php
				if (isset($subjects)) {
				foreach($subjects as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['subject_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				?>
			</table>

		</td>

		<td width="20">&nbsp;</td>

		<td width="275" valign="top">
 			<table border="0" cellspacing="4" cellpadding="0" width="100%">
 				<tr>
 					<td class="txt_title" align="right">
 						<?php echo $lang['section_polls'];?><br />
 						<hr />
 					</td>
 				</tr>
 				<?php
				if (isset($polls)) {
 				foreach($polls as $key => $i):
 				?>
 				<tr>
 					<td valign="top">
 						<?php
						$poll = $i;
 						include $templatePath . "poll.inc.tpl.php";
 						?>
 					</td>
 			    </tr>
				<tr>
 					<td valign="top" class="txt_footer" align="right">
 						<a href="mag_item.php?poll_id=<?php echo $i['poll_id'];?>" class="txt_footer_lnk">visit poll</a><br />
 					</td>
 			    </tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
 				<?php
 				endforeach;
				}
 				?>
 			</table>
			

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td class="txt_title" align="right">
						<?php echo $lang['section_library_items'];?><br />
						<hr />
					</td>
				</tr>
				<?php
				if (isset($library_items)) {
				foreach($library_items as $key => $i):
				foreach($cms_library_items as $key1 => $cms):
				if (($cms['item_id'] == $i['library_id']) && $cms['cms_sticky'] == 1) {
				unset($library_items[$key]);
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="4" cellspacing="2" border="0" class="picture">
							<tr>
								<td width="80" rowspan="2" valign="top">
									<a href="mag_item.php?library_id=<?php echo $i['library_id'];?>"><img align="left" src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture" title="<?php echo $i['image']['file_title'];?>"></a>
								</td>
								<td valign="top" class="bg2">
									<a href="mag_item.php?library_id=<?php echo $i['library_id'];?>"><?php echo $i['library_title'];?></a><br />
								</td>
							</tr>
							<tr>
								<td valign="top" class="bg4">
									<span class="txt_footer"><?php echo $i['library_create_datetime'];?>
									&nbsp;/&nbsp;
									<?php echo $lang['txt_genre'];?>: <?php if (isset($i['genre_id']) && $i['genre_id'] > 0) { echo $lang['arr_genre'][$i['genre_id']];}?></span><br />
									<span class="txt_footer"><?php echo $i['library_synopsis'];?></span><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				}
				endforeach;
				endforeach;
				}
				?>
				<?php
				if (isset($library_items)) {
				foreach($library_items as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?library_id=<?php echo $i['library_id'];?>"><?php echo $i['library_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['library_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				?>
			</table>
		</td>
	</tr>
</table>
</form>
